@@ -34,7 +34,6 @@ from The Open Group.
 #include <config.h>
 #endif
 #include "libxfontint.h"
-#include "src/util/replace.h"
 
 #include <X11/fonts/fntfilst.h>
 #include <X11/fonts/bitmap.h>
@@ -46,7 +45,6 @@ from The Open Group.
 
 #include <stdarg.h>
 #include <stdint.h>
-#include <string.h>
 
 void
 pcfError(const char* message, ...)
@@ -139,7 +137,7 @@ pcfReadTOC(FontFilePtr file, int *countp)
 	pcfError("pcfReadTOC(): invalid file format\n");
 	return NULL;
     }
-    tables = mallocarray(count, sizeof(PCFTableRec));
+    tables = malloc(count * sizeof(PCFTableRec));
     if (!tables) {
 	pcfError("pcfReadTOC(): Couldn't allocate tables (%d*%d)\n",
 		 count, (int) sizeof(PCFTableRec));
@@ -197,7 +195,7 @@ pcfGetCompressedMetric(FontFilePtr file, CARD32 format, xCharInfo *metric)
 }
 
 /*
- * Position the file to the beginning of the specified table
+ * Position the file to the begining of the specified table
  * in the font file
  */
 static Bool
@@ -264,13 +262,13 @@ pcfGetProperties(FontInfoPtr pFontInfo, FontFilePtr file,
 	goto Bail;
     }
     if (IS_EOF(file)) goto Bail;
-    props = mallocarray(nprops, sizeof(FontPropRec));
+    props = malloc(nprops * sizeof(FontPropRec));
     if (!props) {
 	pcfError("pcfGetProperties(): Couldn't allocate props (%d*%d)\n",
 	       nprops, (int) sizeof(FontPropRec));
 	goto Bail;
     }
-    isStringProp = mallocarray(nprops, sizeof(char));
+    isStringProp = malloc(nprops * sizeof(char));
     if (!isStringProp) {
 	pcfError("pcfGetProperties(): Couldn't allocate isStringProp (%d*%d)\n",
 	       nprops, (int) sizeof(char));
@@ -313,19 +311,11 @@ pcfGetProperties(FontInfoPtr pFontInfo, FontFilePtr file,
     if (IS_EOF(file)) goto Bail;
     position += string_size;
     for (i = 0; i < nprops; i++) {
-	if (props[i].name >= string_size) {
-	    pcfError("pcfGetProperties(): String starts out of bounds (%ld/%d)\n", props[i].name, string_size);
-	    goto Bail;
-	}
 	props[i].name = MakeAtom(strings + props[i].name,
-				 strnlen(strings + props[i].name, string_size - props[i].name), TRUE);
+				 strlen(strings + props[i].name), TRUE);
 	if (isStringProp[i]) {
-	    if (props[i].value >= string_size) {
-		pcfError("pcfGetProperties(): String starts out of bounds (%ld/%d)\n", props[i].value, string_size);
-		goto Bail;
-	    }
 	    props[i].value = MakeAtom(strings + props[i].value,
-				      strnlen(strings + props[i].value, string_size - props[i].value), TRUE);
+				      strlen(strings + props[i].value), TRUE);
 	}
     }
     free(strings);
@@ -457,7 +447,7 @@ pcfReadFont(FontPtr pFont, FontFilePtr file,
 	pcfError("pcfReadFont(): invalid file format\n");
 	goto Bail;
     }
-    metrics = mallocarray(nmetrics, sizeof(CharInfoRec));
+    metrics = malloc(nmetrics * sizeof(CharInfoRec));
     if (!metrics) {
 	pcfError("pcfReadFont(): Couldn't allocate metrics (%d*%d)\n",
 		 nmetrics, (int) sizeof(CharInfoRec));
@@ -484,7 +474,7 @@ pcfReadFont(FontPtr pFont, FontFilePtr file,
     if (nbitmaps != nmetrics || IS_EOF(file))
 	goto Bail;
     /* nmetrics is already ok, so nbitmap also is */
-    offsets = mallocarray(nbitmaps, sizeof(CARD32));
+    offsets = malloc(nbitmaps * sizeof(CARD32));
     if (!offsets) {
 	pcfError("pcfReadFont(): Couldn't allocate offsets (%d*%d)\n",
 		 nbitmaps, (int) sizeof(CARD32));
@@ -574,7 +564,7 @@ pcfReadFont(FontPtr pFont, FontFilePtr file,
 	if (nink_metrics != nmetrics)
 	    goto Bail;
 	/* nmetrics already checked */
-	ink_metrics = mallocarray(nink_metrics, sizeof(xCharInfo));
+	ink_metrics = malloc(nink_metrics * sizeof(xCharInfo));
 	if (!ink_metrics) {
             pcfError("pcfReadFont(): Couldn't allocate ink_metrics (%d*%d)\n",
 		     nink_metrics, (int) sizeof(xCharInfo));
