@@ -54,7 +54,6 @@ in this Software without prior written authorization from The Open Group.
 #include <config.h>
 #endif
 #include "libxfontint.h"
-#include "src/util/replace.h"
 
 #ifdef WIN32
 #define _WILLWINSOCK_
@@ -224,8 +223,8 @@ _fs_add_rep_log (FSFpePtr conn, fsGenericReply *rep)
             fprintf (stderr, "Error: %d Request: %s\n",                 \
                      ((fsError *)rep)->request, #name);                 \
         else                                                            \
-            fprintf (stderr, "Bad Length for %s Reply: %u %s %d\n",     \
-                     #name, (unsigned) rep->length, op, LENGTHOF(name));\
+            fprintf (stderr, "Bad Length for %s Reply: %d %s %d\n",     \
+                     #name, rep->length, op, LENGTHOF(name));           \
     }                                                                   \
 } while (0)
 
@@ -650,8 +649,8 @@ fs_get_reply (FSFpePtr conn, int *error)
      */
     if (rep->length > MAX_REPLY_LENGTH)
     {
-	ErrorF("fserve: reply length %ld > MAX_REPLY_LENGTH, disconnecting"
-	       " from font server\n", (long)rep->length);
+	ErrorF("fserve: reply length %d > MAX_REPLY_LENGTH, disconnecting"
+	       " from font server\n", rep->length);
 	_fs_connection_died (conn);
 	*error = FSIO_ERROR;
 	return 0;
@@ -934,8 +933,8 @@ fs_read_query_info(FontPathElementPtr fpe, FSBlockDataPtr blockrec)
 	ret = -1;
 #ifdef DEBUG
 	fprintf(stderr,
-		"fsQueryXInfo: bufleft (%ld) / SIZEOF(fsPropOffset) < %u\n",
-		bufleft, (unsigned) pi->num_offsets);
+		"fsQueryXInfo: bufleft (%ld) / SIZEOF(fsPropOffset) < %d\n",
+		bufleft, pi->num_offsets);
 #endif
 	goto bail;
     }
@@ -948,8 +947,8 @@ fs_read_query_info(FontPathElementPtr fpe, FSBlockDataPtr blockrec)
 	ret = -1;
 #ifdef DEBUG
 	fprintf(stderr,
-		"fsQueryXInfo: bufleft (%ld) < data_len (%u)\n",
-		bufleft, (unsigned) pi->data_len);
+		"fsQueryXInfo: bufleft (%ld) < data_len (%d)\n",
+		bufleft, pi->data_len);
 #endif
 	goto bail;
     }
@@ -1082,14 +1081,14 @@ fs_read_extent_info(FontPathElementPtr fpe, FSBlockDataPtr blockrec)
 			    / LENGTHOF(fsXCharInfo))) {
 #ifdef DEBUG
 	fprintf(stderr,
-		"fsQueryXExtents16: numExtents (%d) > (%u - %d) / %d\n",
-		numExtents, (unsigned) rep->length,
+		"fsQueryXExtents16: numExtents (%d) > (%d - %d) / %d\n",
+		numExtents, rep->length,
 		LENGTHOF(fsQueryXExtents16Reply), LENGTHOF(fsXCharInfo));
 #endif
 	pCI = NULL;
     }
     else
-	pCI = mallocarray(numInfos, sizeof(CharInfoRec));
+	pCI = malloc(sizeof(CharInfoRec) * numInfos);
 
     if (!pCI)
     {
@@ -1958,8 +1957,8 @@ fs_read_glyphs(FontPathElementPtr fpe, FSBlockDataPtr blockrec)
     {
 #ifdef DEBUG
 	fprintf(stderr,
-		"fsQueryXBitmaps16: num_chars (%u) > bufleft (%ld) / %d\n",
-		(unsigned) rep->num_chars, bufleft, SIZEOF (fsOffset32));
+		"fsQueryXBitmaps16: num_chars (%d) > bufleft (%ld) / %d\n",
+		rep->num_chars, bufleft, SIZEOF (fsOffset32));
 #endif
 	err = AllocError;
 	goto bail;
@@ -1972,8 +1971,8 @@ fs_read_glyphs(FontPathElementPtr fpe, FSBlockDataPtr blockrec)
     {
 #ifdef DEBUG
 	fprintf(stderr,
-		"fsQueryXBitmaps16: nbytes (%u) > bufleft (%ld)\n",
-		(unsigned) rep->nbytes, bufleft);
+		"fsQueryXBitmaps16: nbytes (%d) > bufleft (%ld)\n",
+		rep->nbytes, bufleft);
 #endif
 	err = AllocError;
 	goto bail;
@@ -2079,8 +2078,7 @@ fs_read_glyphs(FontPathElementPtr fpe, FSBlockDataPtr blockrec)
     err = Successful;
 
 bail:
-    if (rep)
-	_fs_done_read (conn, rep->length << 2);
+    _fs_done_read (conn, rep->length << 2);
     return err;
 }
 
@@ -2575,8 +2573,8 @@ fs_read_list_info(FontPathElementPtr fpe, FSBlockDataPtr blockrec)
     if (pi->num_offsets > (bufleft / SIZEOF (fsPropOffset))) {
 #ifdef DEBUG
 	fprintf(stderr,
-		"fsListFontsWithXInfo: offset length (%u * %d) > bufleft (%ld)\n",
-		(unsigned) pi->num_offsets, (int) SIZEOF (fsPropOffset), bufleft);
+		"fsListFontsWithXInfo: offset length (%d * %d) > bufleft (%ld)\n",
+		pi->num_offsets, (int) SIZEOF (fsPropOffset), bufleft);
 #endif
 	err = AllocError;
 	goto done;
@@ -2587,8 +2585,8 @@ fs_read_list_info(FontPathElementPtr fpe, FSBlockDataPtr blockrec)
     if (pi->data_len > bufleft) {
 #ifdef DEBUG
 	fprintf(stderr,
-		"fsListFontsWithXInfo: data length (%u) > bufleft (%ld)\n",
-		(unsigned) pi->data_len, bufleft);
+		"fsListFontsWithXInfo: data length (%d) > bufleft (%ld)\n",
+		pi->data_len, bufleft);
 #endif
 	err = AllocError;
 	goto done;
@@ -2858,12 +2856,14 @@ _fs_client_access (FSFpePtr conn, pointer client, Bool sync)
 	if (crac.num_auths == 0) {
 	    authorizations = padding;
 	    authlen = 4;
+	} else {
+	    authlen = (authlen + 3) & ~0x3;
 	}
 	crac.length = (sizeof (fsCreateACReq) + authlen) >> 2;
 	crac.acid = cur->acid;
 	_fs_add_req_log(conn, FS_CreateAC);
 	_fs_write(conn, (char *) &crac, sizeof (fsCreateACReq));
-	_fs_write_pad(conn, authorizations, authlen);
+	_fs_write(conn, authorizations, authlen);
 	/* ignore reply; we don't even care about it */
 	conn->curacid = 0;
 	cur->auth_generation = client_auth_generation(client);
@@ -3371,9 +3371,8 @@ static FSFpePtr
 _fs_init_conn (const char *servername, FontPathElementPtr fpe)
 {
     FSFpePtr	conn;
-    size_t	snlen = strlen (servername) + 1;
 
-    conn = calloc (1, sizeof (FSFpeRec) + snlen);
+    conn = calloc (1, sizeof (FSFpeRec) + strlen (servername) + 1);
     if (!conn)
 	return 0;
     if (!_fs_io_init (conn))
@@ -3385,7 +3384,7 @@ _fs_init_conn (const char *servername, FontPathElementPtr fpe)
     conn->fs_conn_state = FS_CONN_UNCONNECTED;
     conn->fs_fd = -1;
     conn->fpe = fpe;
-    strlcpy (conn->servername, servername, snlen);
+    strcpy (conn->servername, servername);
     return conn;
 }
 
