@@ -35,7 +35,6 @@
 #include <sys/stat.h>
 #include <dirent.h>
 #include <unistd.h>
-#include "src/util/replace.h"
 
 static const char CataloguePrefix[] = "catalogue:";
 
@@ -65,8 +64,7 @@ CatalogueAddFPE (CataloguePtr cat, FontPathElementPtr fpe)
 	else
 	    cat->fpeAlloc *= 2;
 
-	new = reallocarray(cat->fpeList, cat->fpeAlloc,
-			   sizeof(FontPathElementPtr));
+	new = realloc(cat->fpeList, cat->fpeAlloc * sizeof(FontPathElementPtr));
 	if (new == NULL)
 	    return AllocError;
 
@@ -151,12 +149,14 @@ CatalogueRescan (FontPathElementPtr fpe, Bool forceScan)
     if ((forceScan == FALSE) && (statbuf.st_mtime <= cat->mtime))
 	return Successful;
 
-    CatalogueUnrefFPEs (fpe);
-
     dir = opendir(path);
     if (dir == NULL)
+    {
+	free(cat);
 	return BadFontPath;
+    }
 
+    CatalogueUnrefFPEs (fpe);
     while (entry = readdir(dir), entry != NULL)
     {
         char *name;
