@@ -34,7 +34,6 @@ in this Software without prior written authorization from The Open Group.
 #include "libxfontint.h"
 #include    <X11/fonts/fntfilst.h>
 #include    <X11/keysym.h>
-#include "src/util/replace.h"
 
 #if HAVE_STDINT_H
 #include <stdint.h>
@@ -49,7 +48,7 @@ FontFileInitTable (FontTablePtr table, int size)
 	return FALSE;
     if (size)
     {
-	table->entries = mallocarray(size, sizeof(FontEntryRec));
+	table->entries = malloc(sizeof(FontEntryRec) * size);
 	if (!table->entries)
 	    return FALSE;
     }
@@ -112,12 +111,11 @@ FontFileMakeDir(const char *dirName, int size)
     const char		*attrib;
     int			attriblen;
 
+#if !defined(WIN32)
     attrib = strchr(dirName, ':');
-#if defined(WIN32)
-    if (attrib && attrib - dirName == 1) {
-	/* WIN32 uses the colon in the drive letter descriptor, skip this */
-	attrib = strchr(dirName + 2, ':');
-    }
+#else
+    /* OS/2 uses the colon in the drive letter descriptor, skip this */
+    attrib = strchr(dirName+2, ':');
 #endif
     if (attrib) {
 	dirlen = attrib - dirName;
@@ -126,7 +124,10 @@ FontFileMakeDir(const char *dirName, int size)
 	dirlen = strlen(dirName);
 	attriblen = 0;
     }
-    if (dirlen && dirName[dirlen - 1] != '/')
+    if (dirName[dirlen - 1] != '/')
+#ifdef NCD
+    if (dirlen)     /* leave out slash for builtins */
+#endif
 	needslash = 1;
     dir = malloc(sizeof *dir + dirlen + needslash + 1 +
 		 (attriblen ? attriblen + 1 : 0));
@@ -151,11 +152,11 @@ FontFileMakeDir(const char *dirName, int size)
     else
 	dir->attributes = NULL;
     strncpy(dir->directory, dirName, dirlen);
-    if (needslash)
-	dir->directory[dirlen] = '/';
-    dir->directory[dirlen + needslash] = '\0';
+    dir->directory[dirlen] = '\0';
     if (dir->attributes)
-	strlcpy(dir->attributes, attrib, attriblen + 1);
+	strcpy(dir->attributes, attrib);
+    if (needslash)
+	strcat(dir->directory, "/");
     return dir;
 }
 
@@ -183,7 +184,7 @@ FontFileAddEntry(FontTablePtr table, FontEntryPtr prototype)
 	       directory that we should just give up before we overflow. */
 	    return NULL;
 	newsize = table->size + 100;
-	entry = reallocarray(table->entries, newsize, sizeof(FontEntryRec));
+	entry = realloc(table->entries, newsize * sizeof(FontEntryRec));
 	if (!entry)
 	    return (FontEntryPtr)0;
 	table->size = newsize;
@@ -399,10 +400,8 @@ PatternMatch(char *pat, int patdashes, char *string, int stringdashes)
 		}
 	    }
 	case '?':
-	    if ((t = *string++) == XK_minus)
+	    if (*string++ == XK_minus)
 		stringdashes--;
-	    if (!t)
-		return 0;
 	    break;
 	case '\0':
 	    return (*string == '\0');
